@@ -204,6 +204,14 @@
 #'  (Spearman's rho) of each dependent variable between each dependent
 #'  variable value and time.
 #'
+#'  Normalize_method (for user's reference)
+#'
+#'  When data_type is either "measurement" or "others", this table shows the
+#'  normalization method used for each feature. Please refer to "Using the
+#'  bestNormalize Package" on the Internet for the details of each method.
+#'  "NA" indicates that there are too few data points to interpolate, and
+#'  thus no normalization was done.
+#'
 #' @examples
 #' test_cont <- suppressWarnings(longdat_cont(input = LongDat_cont_master_table,
 #' data_type = "count", test_var = "Day",
@@ -261,9 +269,18 @@ longdat_cont <- function(input, data_type, test_var, variable_col, fac_var,
   }
   ################## Null Model Test #################
   if (verbose == TRUE) {print("Start null model test.")}
-  Ps_null_model <- as.data.frame(NuModelTest_cont(N, data_type, test_var,
-                                                  melt_data, variables,
-                                                  verbose))
+
+  if (data_type %in% c("measurement", "others")) {
+    Ps_null_model_list <- NuModelTest_cont(N, data_type, test_var,
+                                           melt_data, variables,
+                                           verbose)
+    Ps_null_model <- Ps_null_model_list[[1]]
+    Normalize_method <- Ps_null_model_list[[2]]
+  } else {
+    Ps_null_model <- as.data.frame(NuModelTest_cont(N, data_type, test_var,
+                                                    melt_data, variables,
+                                                    verbose))
+  }
   if (verbose == TRUE) {print("Finish null model test.")}
 
   ################## Covariate model test ###############
@@ -326,7 +343,11 @@ longdat_cont <- function(input, data_type, test_var, variable_col, fac_var,
     rownames(Ps_conf_inv_model_unlist) <- variables_original
   }
 
-  ######################### Remove the excluded ones #########################
+  if (data_type %in% c("measurement", "others")) {
+    Normalize_method$Feature <- variables_original
+  }
+
+  ############## Remove the excluded one when data_type = count ##########
   if (data_type == "count") {
     if (verbose == TRUE) {print(
       "Start removing the dependent variables to be exlcuded.")}
@@ -397,9 +418,10 @@ longdat_cont <- function(input, data_type, test_var, variable_col, fac_var,
   if (data_type == "count") {
     if (false_pos_count > 0) {
       print(paste0("Attention! Since there are false positives in the ",
-            "randomized control test, it's recommended to check the ",
-            "effect sizes of the significant signals and rule out the ones ",
-            "with low effect sizes. See the documentation for more details."))
+                   "randomized control test, it's recommended to check the ",
+                   "effect sizes of the significant signals and rule out the
+                   ones ", "with low effect sizes. See the documentation for
+                   more details."))
     }
   }
 
@@ -424,7 +446,16 @@ longdat_cont <- function(input, data_type, test_var, variable_col, fac_var,
                   Covariate_table = Confounder_table))
     } else if (false_pos_count == 0 & variable_col-1-2-length(not_used) == 0) {
       return(list(Result_table = Result_table))}
-  } else if(data_type != "count") {
+  } else if(data_type %in% c("measurement", "others")) {
+    if (variable_col-1-2-length(not_used) > 0) {
+      return(list(Result_table = Result_table,
+                  Covariate_table = Confounder_table,
+                  Normalize_method = Normalize_method))
+    } else if (variable_col-1-2-length(not_used) == 0) {
+      return(Result_table = Result_table,
+             Normalize_method = Normalize_method)
+    }
+  } else if(data_type %in% c("proportion", "binary", "ordinal")) {
     if (variable_col-1-2-length(not_used) > 0) {
       return(list(Result_table = Result_table,
                   Covariate_table = Confounder_table))
@@ -433,3 +464,4 @@ longdat_cont <- function(input, data_type, test_var, variable_col, fac_var,
     }
   }
 }
+
